@@ -28,7 +28,7 @@ whose conditions may differ from those of your experiment.
 __docformat__ = 'restructuredtext en'
 __all__ = ['elements', 'neutron_sld','xray_sld',
            'formula','mix_by_weight','mix_by_volume'] # and all elements
-__version__ = "1.3.0"
+__version__ = "1.3.2"
 
 from . import core
 from . import mass
@@ -58,7 +58,8 @@ def data_files():
         return files
 
     data_files = [('periodictable-data/xsf',
-                   _finddata('xsf', ['*.nff','read.me','f0_WaasKirf.dat']))]
+                   _finddata('xsf', ['*.nff','read.me','f0_WaasKirf.dat'])),
+                  ('periodictable-data', 'activation.dat')]
     return data_files
 
 # Export variables for each element name and symbol.
@@ -100,6 +101,19 @@ def _load_neutron():
     nsf.init(elements)
 core.delayed_load(['neutron'],_load_neutron, isotope=True)
 
+def _load_neutron_activation():
+    """
+    Neutron activation calculations for isotopes and formulas.
+
+    Reference:
+        *IAEA 273: Handbook on Nuclear Activation Data.*
+        *NBSIR 85-3151: Compendium of Benchmark Neutron Field.*
+    """
+    from . import activation
+    activation.init(elements)
+core.delayed_load(['neutron_activation'], _load_neutron_activation, 
+                  element=False, isotope=True)
+
 def _load_xray():
     """
     X-ray scattering properties for the elements.
